package com.ztmap.project.zhny.strategytarget.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ztmap.project.zhny.strategytarget.mapper.TStrategyTargetMapper;
import com.ztmap.project.zhny.strategytarget.domain.TStrategyTarget;
import com.ztmap.project.zhny.strategytarget.service.ITStrategyTargetService;
import com.ztmap.common.utils.text.Convert;

/**
 * 目标Service业务层处理
 * 
 * @author ztmap
 * @date 2023-10-11
 */
@Service
public class TStrategyTargetServiceImpl implements ITStrategyTargetService 
{
    @Autowired
    private TStrategyTargetMapper tStrategyTargetMapper;

    /**
     * 查询目标
     * 
     * @param id 目标ID
     * @return 目标
     */
    @Override
    public TStrategyTarget selectTStrategyTargetById(Long id)
    {
        return tStrategyTargetMapper.selectTStrategyTargetById(id);
    }

    /**
     * 查询目标列表
     * 
     * @param tStrategyTarget 目标
     * @return 目标
     */
    @Override
    public List<TStrategyTarget> selectTStrategyTargetList(TStrategyTarget tStrategyTarget)
    {
        return tStrategyTargetMapper.selectTStrategyTargetList(tStrategyTarget);
    }

    /**
     * 新增目标
     * 
     * @param tStrategyTarget 目标
     * @return 结果
     */
    @Override
    public int insertTStrategyTarget(TStrategyTarget tStrategyTarget)
    {
        return tStrategyTargetMapper.insertTStrategyTarget(tStrategyTarget);
    }

    /**
     * 修改目标
     * 
     * @param tStrategyTarget 目标
     * @return 结果
     */
    @Override
    public int updateTStrategyTarget(TStrategyTarget tStrategyTarget)
    {
        return tStrategyTargetMapper.updateTStrategyTarget(tStrategyTarget);
    }

    /**
     * 删除目标对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTStrategyTargetByIds(String ids)
    {
        return tStrategyTargetMapper.deleteTStrategyTargetByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除目标信息
     * 
     * @param id 目标ID
     * @return 结果
     */
    @Override
    public int deleteTStrategyTargetById(Long id)
    {
        return tStrategyTargetMapper.deleteTStrategyTargetById(id);
    }
}
